/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlBinop.h"
#include "HvMath.h"
#include "HvControlVar.h"
#include "HvSignalBiquad.h"
#include "HvControlIf.h"
#include "HvSignalVar.h"
#include "HvControlSlice.h"
#include "HvSignalLine.h"
#include "HvControlSystem.h"
#include "HvControlCast.h"
#include "HvControlUnop.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_aVQubAsN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wHU76vPS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OmhaNkc4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vyLOtvLt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_V23uxdCw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_arXZjXun_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_r25jmJmK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_R1CXyloT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6KOyWkKF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Ac5a7EW5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OsIhT8jp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9MAYM56S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l6OXZ7N3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p72acc6r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E6UIXpdv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kmfHDiEJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1TgMBNyZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NGwmAuOo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VhiaNl4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YgI3YeSQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JSYrkf0w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QTv9z482_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zo6JLskQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_13SNOoEX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OhstKtgR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EXZPasG6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8wK9IjkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_q6PeaFtb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9O5GiAEy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6y6AcBQ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8ARqW0Po_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TKU700Im_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cXvmhdXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GS6EsQ1Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7Tqb9e9h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B7jHITLw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OQU5tZbS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Wz9E6hX4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UsIo7FGC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fr50u4XZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tqxEsSLr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uorJjYOj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pVdyzHdK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0ASZMk8b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mf1DfFMp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RqqzzJk7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dKLU2JWB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UR77EEjr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GrkmuIfc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lOcSNO64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ruww5DP5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6jsRa7hZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QSGUJr2L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EyjEHY9W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xGKTlK5z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Uidn9Pau_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ktijEGBB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WXSY0bz7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qrqJOF04_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FGxxQ9yV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dHrp6kNh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fgQYtXa1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hc4aV5JA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t1tr4I1u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sBRjmArs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l4av0Hzx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Jex5iJlk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BsxxXiPa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BSjlgzw5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I42Sl3fp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SRRBaZ0T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j4Bp0EBw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ne9SDcM8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sWhmREcb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KmXmIhKo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pKKy9wew_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6rUea71h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bE3ztTV3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_nWdb6sXM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_yoQAJc7U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yeWxN7I8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_igJPnApW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dEjbQF1b_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_zMj27XKM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dkBMDHB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_23kHkFZX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_QGXNOqxt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_GPZP8h5b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NjI1hE9n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_J0rnAlyl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_FcQVwiVB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Ux6Mnopb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_H594JBEb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_aVbcjO5N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nR5mpo2F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lJNv5PjU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ua43sJIY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8oyzIVh3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YG8lc85D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YEJDCW8x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1xdtRiv3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_zMjHDqtW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cQyyTCFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fa2UU52R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2yxxeg98_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rj5yWcjk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9Ad02yNl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_klu37tHa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_EPB9YIDj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PrxTpKwj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WNlKGW1o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZmHSzYR5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KCtG7ZZz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ALVoIzk6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eMoZa8mp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ePOW9nMy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vgdkv6jh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0UmL64nL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T4bpUgrS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GWvMzpxY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qKhGSYJ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_70fDWDA6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AmMUmKCk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9h9Dj0yN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w0P6ihWF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ykJV2ZjX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SXBSPk3L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h9YWGIbV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_112msdKs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Z5juGCAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_X4ndWniJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UvTtJN4S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_meJDt0YP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ujNtZGnb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UGSm2h7B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V4rIIK8F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3AlV0QZs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gd5HO4w2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CHrpt4JZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_grQa8Kxe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Swwj1nl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iLnX9uhG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4NHWhLxu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EEsyKB1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PffBWT9G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_w3p0wgps_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fBn2uUDy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QRsjjrkg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rNtOEVtr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rMTWlZsV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2deYn0a9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5Vq8XsiP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9eckRXJQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0O2p9tJ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WRYCk1cs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HulMgypv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5xfJbP97_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZBcqDCE7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_CZ6TpOQB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IETwg3bN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4pujxXuD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RDUl6fDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qyzEKAAo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FkZTqbsZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_AS01xsiP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_rtTpxt1k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_luMAYM2F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wGYw69EO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zRfNQcYr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7SNarT46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bWzauPQW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VorQiy3G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SdK5vBHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lEtN6yfh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x7P7bGZu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_I87d3j2O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sjYkaP5I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZeOiwW8w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V7SfUYCG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oCLxsZp7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_skIWwhef_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_luWdr0kN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_rjIIAacZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o1VRgfXM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dYdxGlMD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dnE6Bw64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jyb9z75D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VNT66Iqh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jyfyx4fm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qeaRKAEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qu5ireyE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FRsy893i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A1TqS3cs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Dmo3DuIE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tvzkm2ql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2jC68mOw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cvuRaso2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QfxBFs3l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o8OzpOUu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y25488mg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Dd2nwZZ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7PSIXsg7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Fu2y6Ik8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S550Na2j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XApBVcgl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pbhPgWhb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i9xsdpsa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Oopc8dKF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_HkWU9aas_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tpoJplai_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Je5k8v9Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FWtMGqW3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0ZLkOqlM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3FOreUqv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_fJ3cgrxE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_kParVIVH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4ql9toud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6rqoD4Z8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LQUVtWSA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wU088v5C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KY6k0zkq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DXQ3SuZp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6dLPZlfx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oVxcbalH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ORmtICVJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5KD2NMDo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0xWJiYxf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c62DBlac_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jEWBc9aX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j8rk5xJ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p3EdGTFf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iPkMYnMK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bINV4q0L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_T9nwT3Aw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zSW6yPMg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c0UsNffp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GcA3wLTU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_T3wTIxED_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VvZUcvYG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UbLgWJdo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yh6S850a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7bYxFmsK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ivs0sSkq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tb6HRGm6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dygRtmWn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pXwRzvT8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1iBsTF5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1WBRMWZ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DaVPPdmc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YT7TS34D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TkOUV4mR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pqDyF9fA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0VRf9YTM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u3iOU0oS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s1ATStYY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WQ6dZRZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r4ki3oCk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bLBvxj9w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MU0RxAVD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CwykWJCL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DFJLUVTT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2pXzwFOH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PyFdNHOc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0n75xRao_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_suEuPGjM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JrDQJsBO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_z0evnlOy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vXd8BYpw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bzsGlGZ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BW3Bbtig_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ewC4JSbc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_f3PlyNtx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3vteROtA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LBZ1RNws_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kqCfYuVU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sxtnPTCE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pSz2grCt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_88cBh9vW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TWEGiNd8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_enReC9Kz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YhTgZsLH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_m5CuNc4b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uVJoH61B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LL1EabX7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5GGUcm9e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0hBAIrlw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2BlGqQad_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hA2stBOX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_im8WPbnv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KVDyKKWp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mjfigpf1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K4iBp7Jz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Oz6ac1Kr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Bww23moo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LC7hqA0S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8fkifQ40_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_beyGVSKZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QJrsu8Ft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fsi0I5tC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6ewYkV0z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x3rn21zM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PGrnIXJJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bnWNUSIG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZidSqZVR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_35n9P38p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9TbEhcSr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_21QawzfG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_juFmLUZk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5DEgUPCP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r5GSKOHR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GEwreChK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VBDu5clu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N7nNrvHe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4CUFfPqi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iItLpJbc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PYqIhsZw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_A6njd7AA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_giqoWyec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y13i82Qk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MtPrc70u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TNEQxUaR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r8trufRd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cFk1hiZm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YaoADLht_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_trlyH5Ue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eIvbSu7N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t08ZyupX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1fr43FIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7KsrJ0v3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GZByYgw8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d4ouFHJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JEjsZn4t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KRNKSgAv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AeAug9ro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YVFqXXcf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mHHXKkyG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_igRq1Mkb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KGwjWC9t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MKzhCUOQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WDoslhfh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_sJ2u6kyv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RqS8fBDd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_1NHedQ26_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_g8x8wSIa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_l9EgnGga_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ky9cmJcP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qdSznKtB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IeBjGcdK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_qXZ8ByDS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1TLpV01N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Z1vO228q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_aLPK5EWs_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_orCfosXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6u28XLTw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_KCKu4131_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_56HvaWPi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dsIOMgMA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EZHobRwy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IhQRVO1v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8vGgYiCL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hZb5ym3G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SoVPzBbK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jVyRiz4m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ATHtmwpa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_326niIHY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x2QDIIFY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3hkUaz4o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GQ8VxUKQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_mecKFLZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_NHLOwbEx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6gczjV3O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5lJL2UI1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6goZTcFD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5ZY2RnQ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OgwqFQ61_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TZQ7ufI4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oaZhMAIj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_trd20ejU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zm7hwySG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_06GI5laC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9APxdLCP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PbFkyGX6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uTJF122i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CipllCTB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rAj3ZZ4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wCZmAst9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eqO6j9B5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pTvAHpoz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NoYIfNU2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_DXAdxDFT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_TKlz7HXj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_tSmlb9J3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5oplUn31_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SLIFNmYu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ESBXHOJS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EQ5568da_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FeRW48rV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7i6upR6W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6BkTD09Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_52a9BB4n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7zSHITx5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SsZ4fqWM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qH9wGFTT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IOmRt1WA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8XaI7bUE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sJFX2kQ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XV8oUvJ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Za9siurs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lNrWEHiF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cnuk4ztc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XYBCRw5X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VfeF2xm7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aNdtEGgk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pmj5iBHO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C5crmj0D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7Qv6kCWp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xJRoKPhC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Bnv7di6X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1w7zjOi4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_r7kqxltX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BixwouTQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CbEGl6JC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_j3yhJbcH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DRyGb8lU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EAMCiuSH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_UdTXSp7K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_l8g0DyIH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hKCgSRbn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bBb6u28S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wPpoGo7L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KEkFcuhU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lsa9fgyF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xULCWQUd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4AmClfbN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7Kht3Wxn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W5fRflXM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cBKMWtDD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2FCH9opf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_N01Dy80N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_y8jn4drB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t626Ko4Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_pg1aKEmd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9iC4SpNH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hyWe9Odn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e38mbNVk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2K8G2CZX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jf7bcjLV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cfREyQma_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5tRtj7Nq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JIkX5Jj6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WmuRq7Ez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r7EOULvb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ayfhCHKG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QlpOYTD7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vpiWRf2e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kqpA7Kjc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z5wZLjYs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UUr6PNxP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MsTUm1Jf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k1ZReQP1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4dPJa32Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9Y8nD94J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FBkf8Q2G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zjsq49NU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3ihdOjso_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_inEVYvGm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nj0SN0hH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mF1EFyQF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xGRKhOsj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jDFYJkXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rlWaGabF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PJGlILIY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sSlIjZia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uRYUp9Wz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QhUJH3bp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_mlmKafXX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_OJe4ha6h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FeBKWe7Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E0ouLOo2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z2oXQ0t0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3U0x0sca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rIAgbCUm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a0Pw9BER_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OarKfnXI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vUiT5pME_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BCWSLa1C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uZ53aCep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g5gzgZdw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_whDRuC1L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3HdYQByO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_URFuKyRg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kWKYoM3k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uFQCBv4l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PZL30UIE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iBYO8RHh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7bRkfZRZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oW9UJ3SQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_94aHxJ0N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fek5YRsB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_SXbszDxm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_nVLccQPl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_t3Nknogd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q5jqZW1z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VET5sGEu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NCLTv4N0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eTRBgHwq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8OhjejUF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CHOrxyJ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jP3yD1P7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5hWq7rrO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XS7dT96V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oBgRxAxp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_izYMQvX9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Do9Dhnjd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n2i0qsGX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sZl0dKkZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EThXKHc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cLiQkR1r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mvXGwTNT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1QZEfuNB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nw0xXmB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g6fEDp1o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yqHRhYFQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MUfnQLHn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kKN2j45C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FxNi1kOa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zaSizISU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7aAsJz54_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_MLzIOUvH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_DlgaRoQs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O9lyxxEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BhuGOluS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_upwAoUUS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KWYwWKtb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZI7UyPHJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4nLJKgUl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_YPIYjaBz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yA5rcznJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VQDYtH7J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tuvfGzoJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kjT9czOd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sPMWM4CY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tlKtjdJS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kYJcPgoB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LHS3RgiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0tj8GUfK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qlpPlPp6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bzR4RdL7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_n8xc6o3J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vzNNcuCU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tb6H3aWT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vnRpbOHx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ycyxJzS6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8hN75bep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hPyRIota_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0zWrYVET_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GycH2qZp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KeS9LWiw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_okruP0B5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IJFtTV3o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_h9v7t2AR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tR0v7pkq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lBPvZZez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SgbgVlef_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ezLwFjlb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iDsR6sj5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_m13JC8qj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kbvi9wr8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1tWfOj4R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nHCYNoRW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5e2UJcDY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_g6lNnF9T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ekjt0eL7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FJrYEQ6v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AWNizYCs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_E15PK2fi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Udt0tiZI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KkTONK6E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hVpfTqtp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_P3TYVpcd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7u5eT2JW_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_DpD07bQu;
  SignalLine sLine_feYBRk4I;
  SignalLine sLine_B9ItsWCA;
  SignalLine sLine_jGlnr1lF;
  SignalLine sLine_jog8aWbg;
  SignalBiquad sBiquad_s_A6wLjBxN;
  SignalLine sLine_iYvlwkHV;
  SignalLine sLine_NSAt03Yf;
  SignalLine sLine_c6FdOEdK;
  SignalLine sLine_zpYH1D5C;
  SignalBiquad sBiquad_s_lmcRdsEi;
  SignalLine sLine_rGZ9mBSk;
  SignalLine sLine_r9Y1s6bS;
  SignalLine sLine_PW4w6Ga4;
  SignalLine sLine_T9fxe49b;
  SignalLine sLine_9ouyFnr3;
  SignalBiquad sBiquad_s_b6ZTx1Ak;
  SignalLine sLine_VAlCoJtw;
  SignalLine sLine_Vy73cukN;
  SignalLine sLine_wK9gfWib;
  SignalLine sLine_R9e2472K;
  SignalLine sLine_S08T0LJX;
  SignalBiquad sBiquad_s_vaCQd3xC;
  SignalLine sLine_fwnNHNK2;
  SignalLine sLine_AdPVHZZQ;
  SignalLine sLine_liTdNEbW;
  SignalLine sLine_gvy4SBIx;
  SignalBiquad sBiquad_s_rrUUG2Lr;
  SignalLine sLine_n0pdXuFS;
  SignalLine sLine_8x77XGW8;
  SignalLine sLine_rSzxnMeh;
  SignalLine sLine_6C3ptI4k;
  SignalLine sLine_466yTklo;
  SignalBiquad sBiquad_s_XtRHipMX;
  ControlVar cVar_aVQubAsN;
  ControlVar cVar_wHU76vPS;
  ControlVar cVar_OmhaNkc4;
  ControlVar cVar_vyLOtvLt;
  ControlSlice cSlice_arXZjXun;
  ControlVar cVar_r25jmJmK;
  ControlVar cVar_6KOyWkKF;
  ControlIf cIf_Ac5a7EW5;
  ControlIf cIf_OsIhT8jp;
  ControlBinop cBinop_l6OXZ7N3;
  ControlBinop cBinop_p72acc6r;
  ControlBinop cBinop_1TgMBNyZ;
  ControlBinop cBinop_NGwmAuOo;
  ControlBinop cBinop_YgI3YeSQ;
  ControlIf cIf_JSYrkf0w;
  ControlBinop cBinop_QTv9z482;
  ControlBinop cBinop_zo6JLskQ;
  ControlBinop cBinop_OhstKtgR;
  ControlBinop cBinop_EXZPasG6;
  ControlBinop cBinop_8wK9IjkD;
  ControlVar cVar_TKU700Im;
  ControlIf cIf_cXvmhdXF;
  ControlIf cIf_GS6EsQ1Q;
  ControlBinop cBinop_B7jHITLw;
  ControlBinop cBinop_OQU5tZbS;
  ControlBinop cBinop_Fr50u4XZ;
  ControlBinop cBinop_tqxEsSLr;
  ControlBinop cBinop_pVdyzHdK;
  ControlIf cIf_0ASZMk8b;
  ControlBinop cBinop_Mf1DfFMp;
  ControlBinop cBinop_RqqzzJk7;
  ControlBinop cBinop_UR77EEjr;
  ControlBinop cBinop_GrkmuIfc;
  ControlBinop cBinop_lOcSNO64;
  ControlVar cVar_xGKTlK5z;
  ControlIf cIf_Uidn9Pau;
  ControlIf cIf_ktijEGBB;
  ControlBinop cBinop_qrqJOF04;
  ControlBinop cBinop_FGxxQ9yV;
  ControlBinop cBinop_Hc4aV5JA;
  ControlBinop cBinop_t1tr4I1u;
  ControlBinop cBinop_l4av0Hzx;
  ControlIf cIf_Jex5iJlk;
  ControlBinop cBinop_BsxxXiPa;
  ControlBinop cBinop_BSjlgzw5;
  ControlBinop cBinop_SRRBaZ0T;
  ControlBinop cBinop_j4Bp0EBw;
  ControlBinop cBinop_Ne9SDcM8;
  ControlIf cIf_bE3ztTV3;
  ControlSlice cSlice_yoQAJc7U;
  ControlVar cVar_yeWxN7I8;
  ControlSlice cSlice_zMj27XKM;
  ControlVar cVar_dkBMDHB2;
  ControlSlice cSlice_GPZP8h5b;
  ControlVar cVar_NjI1hE9n;
  ControlSlice cSlice_Ux6Mnopb;
  ControlVar cVar_H594JBEb;
  ControlBinop cBinop_Fa2UU52R;
  ControlBinop cBinop_Rj5yWcjk;
  ControlBinop cBinop_9Ad02yNl;
  ControlBinop cBinop_PrxTpKwj;
  ControlBinop cBinop_WNlKGW1o;
  ControlBinop cBinop_ZmHSzYR5;
  ControlBinop cBinop_KCtG7ZZz;
  ControlBinop cBinop_ALVoIzk6;
  ControlVar cVar_eMoZa8mp;
  ControlBinop cBinop_ePOW9nMy;
  ControlBinop cBinop_Vgdkv6jh;
  ControlBinop cBinop_0UmL64nL;
  ControlBinop cBinop_T4bpUgrS;
  ControlBinop cBinop_GWvMzpxY;
  ControlBinop cBinop_qKhGSYJ8;
  ControlBinop cBinop_70fDWDA6;
  ControlBinop cBinop_9h9Dj0yN;
  ControlVar cVar_w0P6ihWF;
  ControlVar cVar_ykJV2ZjX;
  ControlBinop cBinop_meJDt0YP;
  ControlBinop cBinop_ujNtZGnb;
  ControlBinop cBinop_UGSm2h7B;
  ControlBinop cBinop_3AlV0QZs;
  ControlBinop cBinop_gd5HO4w2;
  ControlBinop cBinop_CHrpt4JZ;
  ControlBinop cBinop_grQa8Kxe;
  ControlBinop cBinop_2Swwj1nl;
  ControlBinop cBinop_iLnX9uhG;
  ControlBinop cBinop_4pujxXuD;
  ControlBinop cBinop_qyzEKAAo;
  ControlBinop cBinop_FkZTqbsZ;
  ControlBinop cBinop_luMAYM2F;
  ControlBinop cBinop_wGYw69EO;
  ControlBinop cBinop_zRfNQcYr;
  ControlBinop cBinop_7SNarT46;
  ControlBinop cBinop_bWzauPQW;
  ControlBinop cBinop_VorQiy3G;
  ControlBinop cBinop_SdK5vBHZ;
  ControlBinop cBinop_x7P7bGZu;
  ControlVar cVar_I87d3j2O;
  ControlVar cVar_sjYkaP5I;
  ControlVar cVar_ZeOiwW8w;
  ControlBinop cBinop_dYdxGlMD;
  ControlBinop cBinop_dnE6Bw64;
  ControlBinop cBinop_jyb9z75D;
  ControlBinop cBinop_jyfyx4fm;
  ControlBinop cBinop_qeaRKAEC;
  ControlBinop cBinop_Qu5ireyE;
  ControlBinop cBinop_FRsy893i;
  ControlBinop cBinop_A1TqS3cs;
  ControlBinop cBinop_Je5k8v9Y;
  ControlBinop cBinop_0ZLkOqlM;
  ControlBinop cBinop_3FOreUqv;
  ControlBinop cBinop_4ql9toud;
  ControlBinop cBinop_6rqoD4Z8;
  ControlBinop cBinop_LQUVtWSA;
  ControlBinop cBinop_wU088v5C;
  ControlBinop cBinop_KY6k0zkq;
  ControlBinop cBinop_6dLPZlfx;
  ControlBinop cBinop_ORmtICVJ;
  ControlBinop cBinop_5KD2NMDo;
  ControlBinop cBinop_c62DBlac;
  ControlBinop cBinop_jEWBc9aX;
  ControlBinop cBinop_j8rk5xJ1;
  ControlBinop cBinop_iPkMYnMK;
  ControlVar cVar_bINV4q0L;
  ControlVar cVar_T9nwT3Aw;
  ControlVar cVar_zSW6yPMg;
  ControlBinop cBinop_7bYxFmsK;
  ControlBinop cBinop_ivs0sSkq;
  ControlBinop cBinop_tb6HRGm6;
  ControlBinop cBinop_pXwRzvT8;
  ControlBinop cBinop_1iBsTF5w;
  ControlBinop cBinop_1WBRMWZ1;
  ControlBinop cBinop_DaVPPdmc;
  ControlBinop cBinop_YT7TS34D;
  ControlBinop cBinop_TkOUV4mR;
  ControlBinop cBinop_2pXzwFOH;
  ControlBinop cBinop_0n75xRao;
  ControlBinop cBinop_suEuPGjM;
  SignalVarf sVarf_mkiJYG07;
  SignalVarf sVarf_YM1Rvw3L;
  SignalVarf sVarf_YvRQejEd;
  ControlSlice cSlice_z0evnlOy;
  ControlVar cVar_vXd8BYpw;
  ControlVar cVar_BW3Bbtig;
  ControlIf cIf_ewC4JSbc;
  ControlIf cIf_f3PlyNtx;
  ControlBinop cBinop_LBZ1RNws;
  ControlBinop cBinop_kqCfYuVU;
  ControlBinop cBinop_88cBh9vW;
  ControlBinop cBinop_TWEGiNd8;
  ControlBinop cBinop_YhTgZsLH;
  ControlIf cIf_m5CuNc4b;
  ControlBinop cBinop_uVJoH61B;
  ControlBinop cBinop_LL1EabX7;
  ControlBinop cBinop_0hBAIrlw;
  ControlBinop cBinop_2BlGqQad;
  ControlBinop cBinop_hA2stBOX;
  ControlVar cVar_Oz6ac1Kr;
  ControlIf cIf_Bww23moo;
  ControlIf cIf_LC7hqA0S;
  ControlBinop cBinop_beyGVSKZ;
  ControlBinop cBinop_QJrsu8Ft;
  ControlBinop cBinop_x3rn21zM;
  ControlBinop cBinop_PGrnIXJJ;
  ControlBinop cBinop_ZidSqZVR;
  ControlIf cIf_35n9P38p;
  ControlBinop cBinop_9TbEhcSr;
  ControlBinop cBinop_21QawzfG;
  ControlBinop cBinop_5DEgUPCP;
  ControlBinop cBinop_r5GSKOHR;
  ControlBinop cBinop_GEwreChK;
  ControlVar cVar_PYqIhsZw;
  ControlIf cIf_A6njd7AA;
  ControlIf cIf_giqoWyec;
  ControlBinop cBinop_MtPrc70u;
  ControlBinop cBinop_TNEQxUaR;
  ControlBinop cBinop_YaoADLht;
  ControlBinop cBinop_trlyH5Ue;
  ControlBinop cBinop_t08ZyupX;
  ControlIf cIf_1fr43FIJ;
  ControlBinop cBinop_7KsrJ0v3;
  ControlBinop cBinop_GZByYgw8;
  ControlBinop cBinop_JEjsZn4t;
  ControlBinop cBinop_KRNKSgAv;
  ControlBinop cBinop_AeAug9ro;
  ControlIf cIf_MKzhCUOQ;
  ControlSlice cSlice_sJ2u6kyv;
  ControlVar cVar_RqS8fBDd;
  ControlSlice cSlice_l9EgnGga;
  ControlVar cVar_Ky9cmJcP;
  ControlSlice cSlice_qXZ8ByDS;
  ControlVar cVar_1TLpV01N;
  ControlSlice cSlice_orCfosXP;
  ControlVar cVar_6u28XLTw;
  ControlBinop cBinop_326niIHY;
  ControlBinop cBinop_3hkUaz4o;
  ControlBinop cBinop_GQ8VxUKQ;
  ControlBinop cBinop_6gczjV3O;
  ControlBinop cBinop_5lJL2UI1;
  ControlBinop cBinop_6goZTcFD;
  ControlBinop cBinop_5ZY2RnQ8;
  ControlBinop cBinop_OgwqFQ61;
  ControlVar cVar_TZQ7ufI4;
  ControlBinop cBinop_oaZhMAIj;
  ControlBinop cBinop_trd20ejU;
  ControlBinop cBinop_Zm7hwySG;
  ControlBinop cBinop_06GI5laC;
  ControlBinop cBinop_9APxdLCP;
  ControlBinop cBinop_PbFkyGX6;
  ControlBinop cBinop_uTJF122i;
  ControlBinop cBinop_rAj3ZZ4F;
  ControlVar cVar_wCZmAst9;
  ControlVar cVar_eqO6j9B5;
  ControlBinop cBinop_SLIFNmYu;
  ControlBinop cBinop_ESBXHOJS;
  ControlBinop cBinop_EQ5568da;
  ControlBinop cBinop_7i6upR6W;
  ControlBinop cBinop_6BkTD09Q;
  ControlBinop cBinop_52a9BB4n;
  ControlBinop cBinop_7zSHITx5;
  ControlBinop cBinop_SsZ4fqWM;
  ControlBinop cBinop_qH9wGFTT;
  ControlBinop cBinop_CbEGl6JC;
  ControlBinop cBinop_DRyGb8lU;
  ControlBinop cBinop_EAMCiuSH;
  ControlBinop cBinop_hKCgSRbn;
  ControlBinop cBinop_bBb6u28S;
  ControlBinop cBinop_wPpoGo7L;
  ControlBinop cBinop_KEkFcuhU;
  ControlBinop cBinop_lsa9fgyF;
  ControlBinop cBinop_xULCWQUd;
  ControlBinop cBinop_4AmClfbN;
  ControlBinop cBinop_W5fRflXM;
  ControlVar cVar_cBKMWtDD;
  ControlVar cVar_2FCH9opf;
  ControlVar cVar_N01Dy80N;
  ControlBinop cBinop_2K8G2CZX;
  ControlBinop cBinop_jf7bcjLV;
  ControlBinop cBinop_cfREyQma;
  ControlBinop cBinop_JIkX5Jj6;
  ControlBinop cBinop_WmuRq7Ez;
  ControlBinop cBinop_r7EOULvb;
  ControlBinop cBinop_ayfhCHKG;
  ControlBinop cBinop_QlpOYTD7;
  ControlBinop cBinop_PJGlILIY;
  ControlBinop cBinop_uRYUp9Wz;
  ControlBinop cBinop_QhUJH3bp;
  ControlBinop cBinop_FeBKWe7Y;
  ControlBinop cBinop_E0ouLOo2;
  ControlBinop cBinop_z2oXQ0t0;
  ControlBinop cBinop_3U0x0sca;
  ControlBinop cBinop_rIAgbCUm;
  ControlBinop cBinop_OarKfnXI;
  ControlBinop cBinop_BCWSLa1C;
  ControlBinop cBinop_uZ53aCep;
  ControlBinop cBinop_whDRuC1L;
  ControlBinop cBinop_3HdYQByO;
  ControlBinop cBinop_URFuKyRg;
  ControlBinop cBinop_uFQCBv4l;
  ControlVar cVar_PZL30UIE;
  ControlVar cVar_iBYO8RHh;
  ControlVar cVar_7bRkfZRZ;
  ControlBinop cBinop_q5jqZW1z;
  ControlBinop cBinop_VET5sGEu;
  ControlBinop cBinop_NCLTv4N0;
  ControlBinop cBinop_8OhjejUF;
  ControlBinop cBinop_CHOrxyJ5;
  ControlBinop cBinop_jP3yD1P7;
  ControlBinop cBinop_5hWq7rrO;
  ControlBinop cBinop_XS7dT96V;
  ControlBinop cBinop_oBgRxAxp;
  ControlBinop cBinop_yqHRhYFQ;
  ControlBinop cBinop_kKN2j45C;
  ControlBinop cBinop_FxNi1kOa;
  SignalVarf sVarf_5xfqULeR;
  SignalVarf sVarf_1XFLEcvo;
  SignalVarf sVarf_zo2JYsI9;
  SignalVarf sVarf_MVMAqyeh;
  SignalVarf sVarf_HoQZ2v6O;
  SignalVarf sVarf_Rxx6aCR0;
  SignalVarf sVarf_9qmbTFSr;
  SignalVarf sVarf_lPCGa43t;
  SignalVarf sVarf_QqVNBhLX;
  ControlVar cVar_zaSizISU;
  ControlVar cVar_7aAsJz54;
  ControlBinop cBinop_KWYwWKtb;
  ControlBinop cBinop_ZI7UyPHJ;
  ControlBinop cBinop_4nLJKgUl;
  ControlBinop cBinop_yA5rcznJ;
  ControlBinop cBinop_VQDYtH7J;
  ControlBinop cBinop_tuvfGzoJ;
  ControlBinop cBinop_kjT9czOd;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
