/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_DpD07bQu);
  numBytes += sLine_init(&sLine_feYBRk4I);
  numBytes += sLine_init(&sLine_B9ItsWCA);
  numBytes += sLine_init(&sLine_jGlnr1lF);
  numBytes += sLine_init(&sLine_jog8aWbg);
  numBytes += sBiquad_init(&sBiquad_s_A6wLjBxN);
  numBytes += sLine_init(&sLine_iYvlwkHV);
  numBytes += sLine_init(&sLine_NSAt03Yf);
  numBytes += sLine_init(&sLine_c6FdOEdK);
  numBytes += sLine_init(&sLine_zpYH1D5C);
  numBytes += sBiquad_init(&sBiquad_s_lmcRdsEi);
  numBytes += sLine_init(&sLine_rGZ9mBSk);
  numBytes += sLine_init(&sLine_r9Y1s6bS);
  numBytes += sLine_init(&sLine_PW4w6Ga4);
  numBytes += sLine_init(&sLine_T9fxe49b);
  numBytes += sLine_init(&sLine_9ouyFnr3);
  numBytes += sBiquad_init(&sBiquad_s_b6ZTx1Ak);
  numBytes += sLine_init(&sLine_VAlCoJtw);
  numBytes += sLine_init(&sLine_Vy73cukN);
  numBytes += sLine_init(&sLine_wK9gfWib);
  numBytes += sLine_init(&sLine_R9e2472K);
  numBytes += sLine_init(&sLine_S08T0LJX);
  numBytes += sBiquad_init(&sBiquad_s_vaCQd3xC);
  numBytes += sLine_init(&sLine_fwnNHNK2);
  numBytes += sLine_init(&sLine_AdPVHZZQ);
  numBytes += sLine_init(&sLine_liTdNEbW);
  numBytes += sLine_init(&sLine_gvy4SBIx);
  numBytes += sBiquad_init(&sBiquad_s_rrUUG2Lr);
  numBytes += sLine_init(&sLine_n0pdXuFS);
  numBytes += sLine_init(&sLine_8x77XGW8);
  numBytes += sLine_init(&sLine_rSzxnMeh);
  numBytes += sLine_init(&sLine_6C3ptI4k);
  numBytes += sLine_init(&sLine_466yTklo);
  numBytes += sBiquad_init(&sBiquad_s_XtRHipMX);
  numBytes += cVar_init_f(&cVar_aVQubAsN, 0.0f);
  numBytes += cVar_init_f(&cVar_wHU76vPS, 0.0f);
  numBytes += cVar_init_f(&cVar_OmhaNkc4, 0.0f);
  numBytes += cVar_init_f(&cVar_vyLOtvLt, 0.0f);
  numBytes += cSlice_init(&cSlice_arXZjXun, 1, -1);
  numBytes += cVar_init_f(&cVar_r25jmJmK, 1337.0f);
  numBytes += cVar_init_f(&cVar_6KOyWkKF, 0.0f);
  numBytes += cIf_init(&cIf_Ac5a7EW5, false);
  numBytes += cIf_init(&cIf_OsIhT8jp, false);
  numBytes += cBinop_init(&cBinop_l6OXZ7N3, 0.0f); // __pow
  numBytes += cIf_init(&cIf_JSYrkf0w, false);
  numBytes += cBinop_init(&cBinop_OhstKtgR, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_EXZPasG6, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_8wK9IjkD, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_TKU700Im, 0.0f);
  numBytes += cIf_init(&cIf_cXvmhdXF, false);
  numBytes += cIf_init(&cIf_GS6EsQ1Q, false);
  numBytes += cBinop_init(&cBinop_B7jHITLw, 0.0f); // __pow
  numBytes += cIf_init(&cIf_0ASZMk8b, false);
  numBytes += cBinop_init(&cBinop_UR77EEjr, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_GrkmuIfc, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_lOcSNO64, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_xGKTlK5z, 0.0f);
  numBytes += cIf_init(&cIf_Uidn9Pau, false);
  numBytes += cIf_init(&cIf_ktijEGBB, false);
  numBytes += cBinop_init(&cBinop_qrqJOF04, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Jex5iJlk, false);
  numBytes += cBinop_init(&cBinop_SRRBaZ0T, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_j4Bp0EBw, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Ne9SDcM8, -15.0f); // __eq
  numBytes += cIf_init(&cIf_bE3ztTV3, false);
  numBytes += cSlice_init(&cSlice_yoQAJc7U, 1, -1);
  numBytes += cVar_init_f(&cVar_yeWxN7I8, 0.0f);
  numBytes += cSlice_init(&cSlice_zMj27XKM, 1, -1);
  numBytes += cVar_init_f(&cVar_dkBMDHB2, 0.0f);
  numBytes += cSlice_init(&cSlice_GPZP8h5b, 1, -1);
  numBytes += cVar_init_f(&cVar_NjI1hE9n, 0.0f);
  numBytes += cSlice_init(&cSlice_Ux6Mnopb, 1, -1);
  numBytes += cVar_init_f(&cVar_H594JBEb, 0.313f);
  numBytes += cBinop_init(&cBinop_Rj5yWcjk, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_9Ad02yNl, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_eMoZa8mp, 0.0f);
  numBytes += cVar_init_f(&cVar_w0P6ihWF, 1337.0f);
  numBytes += cVar_init_f(&cVar_ykJV2ZjX, 0.3f);
  numBytes += cBinop_init(&cBinop_ujNtZGnb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gd5HO4w2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CHrpt4JZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_grQa8Kxe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2Swwj1nl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iLnX9uhG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qyzEKAAo, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_FkZTqbsZ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_I87d3j2O, 0.0f);
  numBytes += cVar_init_f(&cVar_sjYkaP5I, 1337.0f);
  numBytes += cVar_init_f(&cVar_ZeOiwW8w, 0.313f);
  numBytes += cBinop_init(&cBinop_dnE6Bw64, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qeaRKAEC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Qu5ireyE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FRsy893i, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_A1TqS3cs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0ZLkOqlM, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_3FOreUqv, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_bINV4q0L, 0.0f);
  numBytes += cVar_init_f(&cVar_T9nwT3Aw, 1037.0f);
  numBytes += cVar_init_f(&cVar_zSW6yPMg, 0.4f);
  numBytes += cBinop_init(&cBinop_ivs0sSkq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1iBsTF5w, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1WBRMWZ1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DaVPPdmc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YT7TS34D, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TkOUV4mR, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_mkiJYG07, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YM1Rvw3L, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YvRQejEd, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_z0evnlOy, 1, -1);
  numBytes += cVar_init_f(&cVar_vXd8BYpw, 1337.0f);
  numBytes += cVar_init_f(&cVar_BW3Bbtig, 0.0f);
  numBytes += cIf_init(&cIf_ewC4JSbc, false);
  numBytes += cIf_init(&cIf_f3PlyNtx, false);
  numBytes += cBinop_init(&cBinop_LBZ1RNws, 0.0f); // __pow
  numBytes += cIf_init(&cIf_m5CuNc4b, false);
  numBytes += cBinop_init(&cBinop_0hBAIrlw, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_2BlGqQad, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_hA2stBOX, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Oz6ac1Kr, 0.0f);
  numBytes += cIf_init(&cIf_Bww23moo, false);
  numBytes += cIf_init(&cIf_LC7hqA0S, false);
  numBytes += cBinop_init(&cBinop_beyGVSKZ, 0.0f); // __pow
  numBytes += cIf_init(&cIf_35n9P38p, false);
  numBytes += cBinop_init(&cBinop_5DEgUPCP, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_r5GSKOHR, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_GEwreChK, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_PYqIhsZw, 0.0f);
  numBytes += cIf_init(&cIf_A6njd7AA, false);
  numBytes += cIf_init(&cIf_giqoWyec, false);
  numBytes += cBinop_init(&cBinop_MtPrc70u, 0.0f); // __pow
  numBytes += cIf_init(&cIf_1fr43FIJ, false);
  numBytes += cBinop_init(&cBinop_JEjsZn4t, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_KRNKSgAv, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_AeAug9ro, -15.0f); // __eq
  numBytes += cIf_init(&cIf_MKzhCUOQ, false);
  numBytes += cSlice_init(&cSlice_sJ2u6kyv, 1, -1);
  numBytes += cVar_init_f(&cVar_RqS8fBDd, 0.0f);
  numBytes += cSlice_init(&cSlice_l9EgnGga, 1, -1);
  numBytes += cVar_init_f(&cVar_Ky9cmJcP, 0.0f);
  numBytes += cSlice_init(&cSlice_qXZ8ByDS, 1, -1);
  numBytes += cVar_init_f(&cVar_1TLpV01N, 0.0f);
  numBytes += cSlice_init(&cSlice_orCfosXP, 1, -1);
  numBytes += cVar_init_f(&cVar_6u28XLTw, 0.313f);
  numBytes += cBinop_init(&cBinop_3hkUaz4o, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_GQ8VxUKQ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_TZQ7ufI4, 0.0f);
  numBytes += cVar_init_f(&cVar_wCZmAst9, 1337.0f);
  numBytes += cVar_init_f(&cVar_eqO6j9B5, 0.3f);
  numBytes += cBinop_init(&cBinop_ESBXHOJS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6BkTD09Q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_52a9BB4n, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7zSHITx5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SsZ4fqWM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qH9wGFTT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DRyGb8lU, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_EAMCiuSH, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_cBKMWtDD, 0.0f);
  numBytes += cVar_init_f(&cVar_2FCH9opf, 1337.0f);
  numBytes += cVar_init_f(&cVar_N01Dy80N, 0.313f);
  numBytes += cBinop_init(&cBinop_jf7bcjLV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WmuRq7Ez, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_r7EOULvb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ayfhCHKG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QlpOYTD7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uRYUp9Wz, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_QhUJH3bp, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_PZL30UIE, 0.0f);
  numBytes += cVar_init_f(&cVar_iBYO8RHh, 1037.0f);
  numBytes += cVar_init_f(&cVar_7bRkfZRZ, 0.4f);
  numBytes += cBinop_init(&cBinop_VET5sGEu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CHOrxyJ5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jP3yD1P7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5hWq7rrO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XS7dT96V, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oBgRxAxp, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_5xfqULeR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1XFLEcvo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zo2JYsI9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MVMAqyeh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HoQZ2v6O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Rxx6aCR0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9qmbTFSr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lPCGa43t, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QqVNBhLX, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_zaSizISU, 5705.6f);
  numBytes += cVar_init_f(&cVar_7aAsJz54, 313.3f);
  numBytes += cBinop_init(&cBinop_KWYwWKtb, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_ZI7UyPHJ, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_4nLJKgUl, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_n8xc6o3J_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tb6H3aWT_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vzNNcuCU_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7u5eT2JW_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8hN75bep_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hPyRIota_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vnRpbOHx_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ycyxJzS6_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0zWrYVET_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IJFtTV3o_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_okruP0B5_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KeS9LWiw_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lBPvZZez_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tR0v7pkq_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_h9v7t2AR_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iDsR6sj5_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ezLwFjlb_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SgbgVlef_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1tWfOj4R_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nHCYNoRW_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m13JC8qj_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kbvi9wr8_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5e2UJcDY_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FJrYEQ6v_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ekjt0eL7_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_g6lNnF9T_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Udt0tiZI_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_E15PK2fi_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AWNizYCs_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P3TYVpcd_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hVpfTqtp_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KkTONK6E_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GycH2qZp_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_aVQubAsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sPMWM4CY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_wHU76vPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tlKtjdJS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_OmhaNkc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kYJcPgoB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_vyLOtvLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LHS3RgiT_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_upwAoUUS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BhuGOluS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O9lyxxEC_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_V23uxdCw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_arXZjXun, 0, m, &cSlice_arXZjXun_sendMessage);
      break;
    }
    default: {
      cSwitchcase_QGXNOqxt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_arXZjXun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_R1CXyloT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_R1CXyloT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_r25jmJmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_R1CXyloT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_R1CXyloT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vnRpbOHx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_6KOyWkKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QTv9z482_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Ac5a7EW5, 0, m, &cIf_Ac5a7EW5_sendMessage);
}

void Heavy_WSTD_EQ::cIf_Ac5a7EW5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_zo6JLskQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_OsIhT8jp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_VhiaNl4M_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_NGwmAuOo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_9MAYM56S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_l6OXZ7N3, HV_BINOP_POW, 0, m, &cBinop_l6OXZ7N3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_l6OXZ7N3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JSYrkf0w, 0, m, &cIf_JSYrkf0w_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_p72acc6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_YgI3YeSQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_E6UIXpdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OsIhT8jp, 0, m, &cIf_OsIhT8jp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_kmfHDiEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1TgMBNyZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1TgMBNyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OsIhT8jp, 1, m, &cIf_OsIhT8jp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NGwmAuOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_p72acc6r_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_VhiaNl4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_JSYrkf0w, 0, m, &cIf_JSYrkf0w_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YgI3YeSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l6OXZ7N3, HV_BINOP_POW, 1, m, &cBinop_l6OXZ7N3_sendMessage);
  cMsg_9MAYM56S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_JSYrkf0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_mkiJYG07, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_QTv9z482_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ac5a7EW5, 1, m, &cIf_Ac5a7EW5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zo6JLskQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EXZPasG6, HV_BINOP_GREATER_THAN, 1, m, &cBinop_EXZPasG6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8wK9IjkD, HV_BINOP_EQ, 1, m, &cBinop_8wK9IjkD_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_13SNOoEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OhstKtgR, HV_BINOP_ADD, 0, m, &cBinop_OhstKtgR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OhstKtgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kmfHDiEJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E6UIXpdv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EXZPasG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JSYrkf0w, 1, m, &cIf_JSYrkf0w_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8wK9IjkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q6PeaFtb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_q6PeaFtb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_mkiJYG07, m);
}

void Heavy_WSTD_EQ::cCast_9O5GiAEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OhstKtgR, HV_BINOP_ADD, 1, m, &cBinop_OhstKtgR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EXZPasG6, HV_BINOP_GREATER_THAN, 0, m, &cBinop_EXZPasG6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8wK9IjkD, HV_BINOP_EQ, 0, m, &cBinop_8wK9IjkD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6y6AcBQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6KOyWkKF, 0, m, &cVar_6KOyWkKF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8ARqW0Po_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_13SNOoEX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_TKU700Im_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Mf1DfFMp_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_cXvmhdXF, 0, m, &cIf_cXvmhdXF_sendMessage);
}

void Heavy_WSTD_EQ::cIf_cXvmhdXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_RqqzzJk7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_GS6EsQ1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_uorJjYOj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_tqxEsSLr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_7Tqb9e9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_B7jHITLw, HV_BINOP_POW, 0, m, &cBinop_B7jHITLw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_B7jHITLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0ASZMk8b, 0, m, &cIf_0ASZMk8b_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OQU5tZbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_pVdyzHdK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Wz9E6hX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GS6EsQ1Q, 0, m, &cIf_GS6EsQ1Q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_UsIo7FGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Fr50u4XZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Fr50u4XZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GS6EsQ1Q, 1, m, &cIf_GS6EsQ1Q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tqxEsSLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_OQU5tZbS_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_uorJjYOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_0ASZMk8b, 0, m, &cIf_0ASZMk8b_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pVdyzHdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B7jHITLw, HV_BINOP_POW, 1, m, &cBinop_B7jHITLw_sendMessage);
  cMsg_7Tqb9e9h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_0ASZMk8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2pXzwFOH_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0n75xRao_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_suEuPGjM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_Mf1DfFMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cXvmhdXF, 1, m, &cIf_cXvmhdXF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RqqzzJk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GrkmuIfc, HV_BINOP_GREATER_THAN, 1, m, &cBinop_GrkmuIfc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lOcSNO64, HV_BINOP_EQ, 1, m, &cBinop_lOcSNO64_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_dKLU2JWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UR77EEjr, HV_BINOP_ADD, 0, m, &cBinop_UR77EEjr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UR77EEjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UsIo7FGC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wz9E6hX4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GrkmuIfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0ASZMk8b, 1, m, &cIf_0ASZMk8b_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lOcSNO64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ruww5DP5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ruww5DP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2pXzwFOH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0n75xRao_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_suEuPGjM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6jsRa7hZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UR77EEjr, HV_BINOP_ADD, 1, m, &cBinop_UR77EEjr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GrkmuIfc, HV_BINOP_GREATER_THAN, 0, m, &cBinop_GrkmuIfc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lOcSNO64, HV_BINOP_EQ, 0, m, &cBinop_lOcSNO64_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QSGUJr2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TKU700Im, 0, m, &cVar_TKU700Im_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EyjEHY9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dKLU2JWB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_xGKTlK5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BsxxXiPa_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Uidn9Pau, 0, m, &cIf_Uidn9Pau_sendMessage);
}

void Heavy_WSTD_EQ::cIf_Uidn9Pau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BSjlgzw5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_ktijEGBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_sBRjmArs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_t1tr4I1u_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_WXSY0bz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qrqJOF04, HV_BINOP_POW, 0, m, &cBinop_qrqJOF04_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qrqJOF04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jex5iJlk, 0, m, &cIf_Jex5iJlk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FGxxQ9yV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_l4av0Hzx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_dHrp6kNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ktijEGBB, 0, m, &cIf_ktijEGBB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fgQYtXa1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Hc4aV5JA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Hc4aV5JA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ktijEGBB, 1, m, &cIf_ktijEGBB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_t1tr4I1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_FGxxQ9yV_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_sBRjmArs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Jex5iJlk, 0, m, &cIf_Jex5iJlk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_l4av0Hzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qrqJOF04, HV_BINOP_POW, 1, m, &cBinop_qrqJOF04_sendMessage);
  cMsg_WXSY0bz7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_Jex5iJlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_YvRQejEd, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_BsxxXiPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Uidn9Pau, 1, m, &cIf_Uidn9Pau_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BSjlgzw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j4Bp0EBw, HV_BINOP_GREATER_THAN, 1, m, &cBinop_j4Bp0EBw_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ne9SDcM8, HV_BINOP_EQ, 1, m, &cBinop_Ne9SDcM8_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_I42Sl3fp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SRRBaZ0T, HV_BINOP_ADD, 0, m, &cBinop_SRRBaZ0T_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SRRBaZ0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fgQYtXa1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dHrp6kNh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_j4Bp0EBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jex5iJlk, 1, m, &cIf_Jex5iJlk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ne9SDcM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sWhmREcb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_sWhmREcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YvRQejEd, m);
}

void Heavy_WSTD_EQ::cCast_KmXmIhKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SRRBaZ0T, HV_BINOP_ADD, 1, m, &cBinop_SRRBaZ0T_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_j4Bp0EBw, HV_BINOP_GREATER_THAN, 0, m, &cBinop_j4Bp0EBw_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ne9SDcM8, HV_BINOP_EQ, 0, m, &cBinop_Ne9SDcM8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pKKy9wew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xGKTlK5z, 0, m, &cVar_xGKTlK5z_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6rUea71h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I42Sl3fp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_bE3ztTV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_YM1Rvw3L, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_nWdb6sXM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yoQAJc7U, 0, m, &cSlice_yoQAJc7U_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dEjbQF1b_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_yoQAJc7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_igJPnApW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_igJPnApW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_yeWxN7I8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_igJPnApW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_igJPnApW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8hN75bep_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_dEjbQF1b_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zMj27XKM, 0, m, &cSlice_zMj27XKM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_V23uxdCw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_zMj27XKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_23kHkFZX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_23kHkFZX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_dkBMDHB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_23kHkFZX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_23kHkFZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0zWrYVET_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_QGXNOqxt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GPZP8h5b, 0, m, &cSlice_GPZP8h5b_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FcQVwiVB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_GPZP8h5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_J0rnAlyl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_J0rnAlyl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_NjI1hE9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_J0rnAlyl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_J0rnAlyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hPyRIota_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_FcQVwiVB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ux6Mnopb, 0, m, &cSlice_Ux6Mnopb_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_Ux6Mnopb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aVbcjO5N_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aVbcjO5N_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_H594JBEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aVbcjO5N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_aVbcjO5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ycyxJzS6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_nR5mpo2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DpD07bQu, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_lJNv5PjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_feYBRk4I, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Ua43sJIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B9ItsWCA, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_8oyzIVh3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jGlnr1lF, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_YG8lc85D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jog8aWbg, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_YEJDCW8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1xdtRiv3_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_1xdtRiv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rj5yWcjk, HV_BINOP_DIVIDE, 1, m, &cBinop_Rj5yWcjk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2yxxeg98_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_zMjHDqtW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Fa2UU52R_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_cQyyTCFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_zMjHDqtW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Fa2UU52R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rj5yWcjk, HV_BINOP_DIVIDE, 0, m, &cBinop_Rj5yWcjk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2yxxeg98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cQyyTCFN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Rj5yWcjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Ad02yNl, HV_BINOP_MULTIPLY, 1, m, &cBinop_9Ad02yNl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9Ad02yNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_h9YWGIbV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SXBSPk3L_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_klu37tHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_112msdKs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_EPB9YIDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Z5juGCAS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_PrxTpKwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_WNlKGW1o_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WNlKGW1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Ad02yNl, HV_BINOP_MULTIPLY, 0, m, &cBinop_9Ad02yNl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZmHSzYR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_KCtG7ZZz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KCtG7ZZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UvTtJN4S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ALVoIzk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eMoZa8mp, 1, m, &cVar_eMoZa8mp_sendMessage);
}

void Heavy_WSTD_EQ::cVar_eMoZa8mp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V4rIIK8F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ePOW9nMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gd5HO4w2, HV_BINOP_MULTIPLY, 1, m, &cBinop_gd5HO4w2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Vgdkv6jh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ePOW9nMy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0UmL64nL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_T4bpUgrS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_T4bpUgrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CHrpt4JZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_CHrpt4JZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GWvMzpxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_grQa8Kxe, HV_BINOP_MULTIPLY, 1, m, &cBinop_grQa8Kxe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qKhGSYJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_GWvMzpxY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_70fDWDA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Swwj1nl, HV_BINOP_MULTIPLY, 1, m, &cBinop_2Swwj1nl_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_AmMUmKCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9h9Dj0yN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9h9Dj0yN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iLnX9uhG, HV_BINOP_MULTIPLY, 1, m, &cBinop_iLnX9uhG_sendMessage);
}

void Heavy_WSTD_EQ::cVar_w0P6ihWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5Vq8XsiP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_PrxTpKwj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2deYn0a9_sendMessage);
}

void Heavy_WSTD_EQ::cVar_ykJV2ZjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ZmHSzYR5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_SXBSPk3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_EPB9YIDj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_h9YWGIbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_klu37tHa_sendMessage);
}

void Heavy_WSTD_EQ::cSend_112msdKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KeS9LWiw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Z5juGCAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_okruP0B5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_X4ndWniJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IJFtTV3o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_UvTtJN4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_meJDt0YP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_meJDt0YP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ujNtZGnb, HV_BINOP_MULTIPLY, 1, m, &cBinop_ujNtZGnb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ujNtZGnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UGSm2h7B_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UGSm2h7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_X4ndWniJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_V4rIIK8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3AlV0QZs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3AlV0QZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PffBWT9G_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rNtOEVtr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fBn2uUDy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rMTWlZsV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QRsjjrkg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w3p0wgps_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gd5HO4w2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nR5mpo2F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_CHrpt4JZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lJNv5PjU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_grQa8Kxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ua43sJIY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_2Swwj1nl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8oyzIVh3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_iLnX9uhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YG8lc85D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_4NHWhLxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w0P6ihWF, 0, m, &cVar_w0P6ihWF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EEsyKB1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ykJV2ZjX, 1, m, &cVar_ykJV2ZjX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PffBWT9G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_w3p0wgps_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gd5HO4w2, HV_BINOP_MULTIPLY, 0, m, &cBinop_gd5HO4w2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fBn2uUDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Swwj1nl, HV_BINOP_MULTIPLY, 0, m, &cBinop_2Swwj1nl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QRsjjrkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CHrpt4JZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_CHrpt4JZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rNtOEVtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iLnX9uhG, HV_BINOP_MULTIPLY, 0, m, &cBinop_iLnX9uhG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rMTWlZsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_grQa8Kxe, HV_BINOP_MULTIPLY, 0, m, &cBinop_grQa8Kxe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2deYn0a9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eMoZa8mp, 0, m, &cVar_eMoZa8mp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5Vq8XsiP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ykJV2ZjX, 0, m, &cVar_ykJV2ZjX_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_9eckRXJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iYvlwkHV, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_0O2p9tJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NSAt03Yf, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_WRYCk1cs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c6FdOEdK, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_HulMgypv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zpYH1D5C, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_5xfJbP97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZBcqDCE7_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_ZBcqDCE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qyzEKAAo, HV_BINOP_DIVIDE, 1, m, &cBinop_qyzEKAAo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RDUl6fDt_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_CZ6TpOQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_4pujxXuD_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_IETwg3bN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_CZ6TpOQB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4pujxXuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qyzEKAAo, HV_BINOP_DIVIDE, 0, m, &cBinop_qyzEKAAo_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RDUl6fDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IETwg3bN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_qyzEKAAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FkZTqbsZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_FkZTqbsZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FkZTqbsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V7SfUYCG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oCLxsZp7_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_AS01xsiP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_skIWwhef_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_rtTpxt1k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_luWdr0kN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_luMAYM2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_wGYw69EO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wGYw69EO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FkZTqbsZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_FkZTqbsZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zRfNQcYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_7SNarT46_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7SNarT46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o1VRgfXM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_bWzauPQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qu5ireyE, HV_BINOP_MULTIPLY, 1, m, &cBinop_Qu5ireyE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VorQiy3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I87d3j2O, 1, m, &cVar_I87d3j2O_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SdK5vBHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FRsy893i, HV_BINOP_MULTIPLY, 1, m, &cBinop_FRsy893i_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_lEtN6yfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_x7P7bGZu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_x7P7bGZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A1TqS3cs, HV_BINOP_MULTIPLY, 1, m, &cBinop_A1TqS3cs_sendMessage);
}

void Heavy_WSTD_EQ::cVar_I87d3j2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VNT66Iqh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_sjYkaP5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2jC68mOw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_luMAYM2F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cvuRaso2_sendMessage);
}

void Heavy_WSTD_EQ::cVar_ZeOiwW8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_zRfNQcYr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_V7SfUYCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_AS01xsiP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oCLxsZp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_rtTpxt1k_sendMessage);
}

void Heavy_WSTD_EQ::cSend_skIWwhef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_h9v7t2AR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_luWdr0kN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tR0v7pkq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_rjIIAacZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lBPvZZez_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_o1VRgfXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_dYdxGlMD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dYdxGlMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dnE6Bw64, HV_BINOP_MULTIPLY, 1, m, &cBinop_dnE6Bw64_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dnE6Bw64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jyb9z75D_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jyb9z75D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rjIIAacZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_VNT66Iqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jyfyx4fm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jyfyx4fm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dd2nwZZ0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o8OzpOUu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QfxBFs3l_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y25488mg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qeaRKAEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9eckRXJQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Qu5ireyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0O2p9tJ4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FRsy893i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WRYCk1cs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_A1TqS3cs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HulMgypv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_Dmo3DuIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZeOiwW8w, 1, m, &cVar_ZeOiwW8w_sendMessage);
}

void Heavy_WSTD_EQ::cCast_tvzkm2ql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sjYkaP5I, 0, m, &cVar_sjYkaP5I_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2jC68mOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZeOiwW8w, 0, m, &cVar_ZeOiwW8w_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cvuRaso2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I87d3j2O, 0, m, &cVar_I87d3j2O_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QfxBFs3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qu5ireyE, HV_BINOP_MULTIPLY, 0, m, &cBinop_Qu5ireyE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_o8OzpOUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FRsy893i, HV_BINOP_MULTIPLY, 0, m, &cBinop_FRsy893i_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Y25488mg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qeaRKAEC, HV_BINOP_MULTIPLY, 0, m, &cBinop_qeaRKAEC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Dd2nwZZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A1TqS3cs, HV_BINOP_MULTIPLY, 0, m, &cBinop_A1TqS3cs_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_7PSIXsg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rGZ9mBSk, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Fu2y6Ik8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r9Y1s6bS, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_S550Na2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PW4w6Ga4, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_XApBVcgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T9fxe49b, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_pbhPgWhb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9ouyFnr3, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_i9xsdpsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Oopc8dKF_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_Oopc8dKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0ZLkOqlM, HV_BINOP_DIVIDE, 1, m, &cBinop_0ZLkOqlM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FWtMGqW3_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_HkWU9aas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Je5k8v9Y_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_tpoJplai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_HkWU9aas_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Je5k8v9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0ZLkOqlM, HV_BINOP_DIVIDE, 0, m, &cBinop_0ZLkOqlM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FWtMGqW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tpoJplai_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_0ZLkOqlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3FOreUqv, HV_BINOP_MULTIPLY, 1, m, &cBinop_3FOreUqv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3FOreUqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GcA3wLTU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c0UsNffp_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_fJ3cgrxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_T3wTIxED_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_kParVIVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VvZUcvYG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_4ql9toud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_6rqoD4Z8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6rqoD4Z8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3FOreUqv, HV_BINOP_MULTIPLY, 0, m, &cBinop_3FOreUqv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LQUVtWSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_wU088v5C_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wU088v5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yh6S850a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_KY6k0zkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1iBsTF5w, HV_BINOP_MULTIPLY, 1, m, &cBinop_1iBsTF5w_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_DXQ3SuZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_6dLPZlfx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6dLPZlfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KY6k0zkq_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_oVxcbalH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ORmtICVJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ORmtICVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1WBRMWZ1, HV_BINOP_MULTIPLY, 1, m, &cBinop_1WBRMWZ1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5KD2NMDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DaVPPdmc, HV_BINOP_MULTIPLY, 1, m, &cBinop_DaVPPdmc_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_0xWJiYxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_c62DBlac_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_c62DBlac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5KD2NMDo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jEWBc9aX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bINV4q0L, 1, m, &cVar_bINV4q0L_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_j8rk5xJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YT7TS34D, HV_BINOP_MULTIPLY, 1, m, &cBinop_YT7TS34D_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_p3EdGTFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_iPkMYnMK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iPkMYnMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TkOUV4mR, HV_BINOP_MULTIPLY, 1, m, &cBinop_TkOUV4mR_sendMessage);
}

void Heavy_WSTD_EQ::cVar_bINV4q0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dygRtmWn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_T9nwT3Aw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CwykWJCL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_4ql9toud_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DFJLUVTT_sendMessage);
}

void Heavy_WSTD_EQ::cVar_zSW6yPMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_LQUVtWSA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_c0UsNffp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_kParVIVH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GcA3wLTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_fJ3cgrxE_sendMessage);
}

void Heavy_WSTD_EQ::cSend_T3wTIxED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SgbgVlef_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_VvZUcvYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ezLwFjlb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_UbLgWJdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iDsR6sj5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Yh6S850a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7bYxFmsK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7bYxFmsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ivs0sSkq, HV_BINOP_MULTIPLY, 1, m, &cBinop_ivs0sSkq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ivs0sSkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tb6HRGm6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tb6HRGm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UbLgWJdo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_dygRtmWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pXwRzvT8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pXwRzvT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s1ATStYY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MU0RxAVD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r4ki3oCk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u3iOU0oS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bLBvxj9w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WQ6dZRZO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1iBsTF5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7PSIXsg7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1WBRMWZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fu2y6Ik8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_DaVPPdmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S550Na2j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_YT7TS34D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XApBVcgl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_TkOUV4mR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pbhPgWhb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_pqDyF9fA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zSW6yPMg, 1, m, &cVar_zSW6yPMg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0VRf9YTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T9nwT3Aw, 0, m, &cVar_T9nwT3Aw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_u3iOU0oS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DaVPPdmc, HV_BINOP_MULTIPLY, 0, m, &cBinop_DaVPPdmc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_s1ATStYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_WQ6dZRZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1iBsTF5w, HV_BINOP_MULTIPLY, 0, m, &cBinop_1iBsTF5w_sendMessage);
}

void Heavy_WSTD_EQ::cCast_r4ki3oCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YT7TS34D, HV_BINOP_MULTIPLY, 0, m, &cBinop_YT7TS34D_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bLBvxj9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1WBRMWZ1, HV_BINOP_MULTIPLY, 0, m, &cBinop_1WBRMWZ1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MU0RxAVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TkOUV4mR, HV_BINOP_MULTIPLY, 0, m, &cBinop_TkOUV4mR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CwykWJCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zSW6yPMg, 0, m, &cVar_zSW6yPMg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DFJLUVTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bINV4q0L, 0, m, &cVar_bINV4q0L_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2pXzwFOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bE3ztTV3, 1, m, &cIf_bE3ztTV3_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_PyFdNHOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YM1Rvw3L, m);
}

void Heavy_WSTD_EQ::cBinop_0n75xRao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PyFdNHOc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_suEuPGjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bE3ztTV3, 0, m, &cIf_bE3ztTV3_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_JrDQJsBO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_z0evnlOy, 0, m, &cSlice_z0evnlOy_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IeBjGcdK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_z0evnlOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bzsGlGZ5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bzsGlGZ5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_vXd8BYpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bzsGlGZ5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_bzsGlGZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_m13JC8qj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_BW3Bbtig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uVJoH61B_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ewC4JSbc, 0, m, &cIf_ewC4JSbc_sendMessage);
}

void Heavy_WSTD_EQ::cIf_ewC4JSbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_LL1EabX7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_f3PlyNtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_enReC9Kz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_TWEGiNd8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_3vteROtA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LBZ1RNws, HV_BINOP_POW, 0, m, &cBinop_LBZ1RNws_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LBZ1RNws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m5CuNc4b, 0, m, &cIf_m5CuNc4b_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kqCfYuVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_YhTgZsLH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sxtnPTCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f3PlyNtx, 0, m, &cIf_f3PlyNtx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pSz2grCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_88cBh9vW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_88cBh9vW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f3PlyNtx, 1, m, &cIf_f3PlyNtx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TWEGiNd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_kqCfYuVU_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_enReC9Kz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_m5CuNc4b, 0, m, &cIf_m5CuNc4b_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YhTgZsLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LBZ1RNws, HV_BINOP_POW, 1, m, &cBinop_LBZ1RNws_sendMessage);
  cMsg_3vteROtA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_m5CuNc4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_5xfqULeR, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_uVJoH61B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ewC4JSbc, 1, m, &cIf_ewC4JSbc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LL1EabX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2BlGqQad, HV_BINOP_GREATER_THAN, 1, m, &cBinop_2BlGqQad_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hA2stBOX, HV_BINOP_EQ, 1, m, &cBinop_hA2stBOX_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_5GGUcm9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0hBAIrlw, HV_BINOP_ADD, 0, m, &cBinop_0hBAIrlw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0hBAIrlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pSz2grCt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sxtnPTCE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2BlGqQad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m5CuNc4b, 1, m, &cIf_m5CuNc4b_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hA2stBOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_im8WPbnv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_im8WPbnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5xfqULeR, m);
}

void Heavy_WSTD_EQ::cCast_KVDyKKWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0hBAIrlw, HV_BINOP_ADD, 1, m, &cBinop_0hBAIrlw_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2BlGqQad, HV_BINOP_GREATER_THAN, 0, m, &cBinop_2BlGqQad_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hA2stBOX, HV_BINOP_EQ, 0, m, &cBinop_hA2stBOX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Mjfigpf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BW3Bbtig, 0, m, &cVar_BW3Bbtig_sendMessage);
}

void Heavy_WSTD_EQ::cCast_K4iBp7Jz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5GGUcm9e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Oz6ac1Kr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9TbEhcSr_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Bww23moo, 0, m, &cIf_Bww23moo_sendMessage);
}

void Heavy_WSTD_EQ::cIf_Bww23moo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_21QawzfG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_LC7hqA0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_bnWNUSIG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_PGrnIXJJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_8fkifQ40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_beyGVSKZ, HV_BINOP_POW, 0, m, &cBinop_beyGVSKZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_beyGVSKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_35n9P38p, 0, m, &cIf_35n9P38p_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QJrsu8Ft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ZidSqZVR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fsi0I5tC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LC7hqA0S, 0, m, &cIf_LC7hqA0S_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6ewYkV0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_x3rn21zM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_x3rn21zM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LC7hqA0S, 1, m, &cIf_LC7hqA0S_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PGrnIXJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_QJrsu8Ft_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_bnWNUSIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_35n9P38p, 0, m, &cIf_35n9P38p_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZidSqZVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_beyGVSKZ, HV_BINOP_POW, 1, m, &cBinop_beyGVSKZ_sendMessage);
  cMsg_8fkifQ40_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_35n9P38p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yqHRhYFQ_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kKN2j45C_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_FxNi1kOa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_9TbEhcSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Bww23moo, 1, m, &cIf_Bww23moo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_21QawzfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r5GSKOHR, HV_BINOP_GREATER_THAN, 1, m, &cBinop_r5GSKOHR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GEwreChK, HV_BINOP_EQ, 1, m, &cBinop_GEwreChK_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_juFmLUZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5DEgUPCP, HV_BINOP_ADD, 0, m, &cBinop_5DEgUPCP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5DEgUPCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6ewYkV0z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fsi0I5tC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_r5GSKOHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_35n9P38p, 1, m, &cIf_35n9P38p_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GEwreChK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VBDu5clu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_VBDu5clu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yqHRhYFQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kKN2j45C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_FxNi1kOa_sendMessage);
}

void Heavy_WSTD_EQ::cCast_N7nNrvHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Oz6ac1Kr, 0, m, &cVar_Oz6ac1Kr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4CUFfPqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_juFmLUZk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_iItLpJbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5DEgUPCP, HV_BINOP_ADD, 1, m, &cBinop_5DEgUPCP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_r5GSKOHR, HV_BINOP_GREATER_THAN, 0, m, &cBinop_r5GSKOHR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GEwreChK, HV_BINOP_EQ, 0, m, &cBinop_GEwreChK_sendMessage);
}

void Heavy_WSTD_EQ::cVar_PYqIhsZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_7KsrJ0v3_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_A6njd7AA, 0, m, &cIf_A6njd7AA_sendMessage);
}

void Heavy_WSTD_EQ::cIf_A6njd7AA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GZByYgw8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_giqoWyec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_eIvbSu7N_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_trlyH5Ue_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_Y13i82Qk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MtPrc70u, HV_BINOP_POW, 0, m, &cBinop_MtPrc70u_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MtPrc70u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1fr43FIJ, 0, m, &cIf_1fr43FIJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TNEQxUaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_t08ZyupX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_r8trufRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_giqoWyec, 0, m, &cIf_giqoWyec_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cFk1hiZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YaoADLht_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YaoADLht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_giqoWyec, 1, m, &cIf_giqoWyec_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_trlyH5Ue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_TNEQxUaR_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_eIvbSu7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_1fr43FIJ, 0, m, &cIf_1fr43FIJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_t08ZyupX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MtPrc70u, HV_BINOP_POW, 1, m, &cBinop_MtPrc70u_sendMessage);
  cMsg_Y13i82Qk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_1fr43FIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_zo2JYsI9, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_7KsrJ0v3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A6njd7AA, 1, m, &cIf_A6njd7AA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GZByYgw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KRNKSgAv, HV_BINOP_GREATER_THAN, 1, m, &cBinop_KRNKSgAv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AeAug9ro, HV_BINOP_EQ, 1, m, &cBinop_AeAug9ro_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_d4ouFHJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JEjsZn4t, HV_BINOP_ADD, 0, m, &cBinop_JEjsZn4t_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JEjsZn4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cFk1hiZm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r8trufRd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KRNKSgAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1fr43FIJ, 1, m, &cIf_1fr43FIJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AeAug9ro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YVFqXXcf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_YVFqXXcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_zo2JYsI9, m);
}

void Heavy_WSTD_EQ::cCast_mHHXKkyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JEjsZn4t, HV_BINOP_ADD, 1, m, &cBinop_JEjsZn4t_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KRNKSgAv, HV_BINOP_GREATER_THAN, 0, m, &cBinop_KRNKSgAv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AeAug9ro, HV_BINOP_EQ, 0, m, &cBinop_AeAug9ro_sendMessage);
}

void Heavy_WSTD_EQ::cCast_igRq1Mkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PYqIhsZw, 0, m, &cVar_PYqIhsZw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_KGwjWC9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d4ouFHJr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_MKzhCUOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_1XFLEcvo, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_WDoslhfh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sJ2u6kyv, 0, m, &cSlice_sJ2u6kyv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_g8x8wSIa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_sJ2u6kyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_1NHedQ26_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_1NHedQ26_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_RqS8fBDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1NHedQ26_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_1NHedQ26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1tWfOj4R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_g8x8wSIa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_l9EgnGga, 0, m, &cSlice_l9EgnGga_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JrDQJsBO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_l9EgnGga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qdSznKtB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qdSznKtB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_Ky9cmJcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qdSznKtB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_qdSznKtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5e2UJcDY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_IeBjGcdK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qXZ8ByDS, 0, m, &cSlice_qXZ8ByDS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_aLPK5EWs_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_qXZ8ByDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Z1vO228q_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Z1vO228q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_1TLpV01N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Z1vO228q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Z1vO228q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nHCYNoRW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_aLPK5EWs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_orCfosXP, 0, m, &cSlice_orCfosXP_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_orCfosXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KCKu4131_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KCKu4131_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_6u28XLTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KCKu4131_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_KCKu4131_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kbvi9wr8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_56HvaWPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VAlCoJtw, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_dsIOMgMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vy73cukN, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_EZHobRwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wK9gfWib, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_IhQRVO1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R9e2472K, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_8vGgYiCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S08T0LJX, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_hZb5ym3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SoVPzBbK_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_SoVPzBbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3hkUaz4o, HV_BINOP_DIVIDE, 1, m, &cBinop_3hkUaz4o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x2QDIIFY_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_jVyRiz4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_326niIHY_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ATHtmwpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_jVyRiz4m_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_326niIHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3hkUaz4o, HV_BINOP_DIVIDE, 0, m, &cBinop_3hkUaz4o_sendMessage);
}

void Heavy_WSTD_EQ::cCast_x2QDIIFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ATHtmwpa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_3hkUaz4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GQ8VxUKQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_GQ8VxUKQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GQ8VxUKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pTvAHpoz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NoYIfNU2_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_mecKFLZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DXAdxDFT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_NHLOwbEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TKlz7HXj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_6gczjV3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_5lJL2UI1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5lJL2UI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GQ8VxUKQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_GQ8VxUKQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6goZTcFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_5ZY2RnQ8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5ZY2RnQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5oplUn31_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_OgwqFQ61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TZQ7ufI4, 1, m, &cVar_TZQ7ufI4_sendMessage);
}

void Heavy_WSTD_EQ::cVar_TZQ7ufI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FeRW48rV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_oaZhMAIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6BkTD09Q, HV_BINOP_MULTIPLY, 1, m, &cBinop_6BkTD09Q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_trd20ejU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oaZhMAIj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Zm7hwySG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_06GI5laC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_06GI5laC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_52a9BB4n, HV_BINOP_MULTIPLY, 1, m, &cBinop_52a9BB4n_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9APxdLCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7zSHITx5, HV_BINOP_MULTIPLY, 1, m, &cBinop_7zSHITx5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PbFkyGX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9APxdLCP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uTJF122i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SsZ4fqWM, HV_BINOP_MULTIPLY, 1, m, &cBinop_SsZ4fqWM_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_CipllCTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rAj3ZZ4F_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rAj3ZZ4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qH9wGFTT, HV_BINOP_MULTIPLY, 1, m, &cBinop_qH9wGFTT_sendMessage);
}

void Heavy_WSTD_EQ::cVar_wCZmAst9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aNdtEGgk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_6gczjV3O_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VfeF2xm7_sendMessage);
}

void Heavy_WSTD_EQ::cVar_eqO6j9B5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_6goZTcFD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pTvAHpoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_mecKFLZH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NoYIfNU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_NHLOwbEx_sendMessage);
}

void Heavy_WSTD_EQ::cSend_DXAdxDFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_g6lNnF9T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_TKlz7HXj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ekjt0eL7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_tSmlb9J3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FJrYEQ6v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_5oplUn31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SLIFNmYu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SLIFNmYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ESBXHOJS, HV_BINOP_MULTIPLY, 1, m, &cBinop_ESBXHOJS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ESBXHOJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EQ5568da_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EQ5568da_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tSmlb9J3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_FeRW48rV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7i6upR6W_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7i6upR6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XV8oUvJ4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XYBCRw5X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lNrWEHiF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sJFX2kQ8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cnuk4ztc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Za9siurs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6BkTD09Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_56HvaWPi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_52a9BB4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dsIOMgMA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_7zSHITx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EZHobRwy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_SsZ4fqWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IhQRVO1v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_qH9wGFTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8vGgYiCL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_IOmRt1WA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wCZmAst9, 0, m, &cVar_wCZmAst9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8XaI7bUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eqO6j9B5, 1, m, &cVar_eqO6j9B5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sJFX2kQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7zSHITx5, HV_BINOP_MULTIPLY, 0, m, &cBinop_7zSHITx5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XV8oUvJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_Za9siurs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6BkTD09Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_6BkTD09Q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lNrWEHiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SsZ4fqWM, HV_BINOP_MULTIPLY, 0, m, &cBinop_SsZ4fqWM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Cnuk4ztc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_52a9BB4n, HV_BINOP_MULTIPLY, 0, m, &cBinop_52a9BB4n_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XYBCRw5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qH9wGFTT, HV_BINOP_MULTIPLY, 0, m, &cBinop_qH9wGFTT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_VfeF2xm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TZQ7ufI4, 0, m, &cVar_TZQ7ufI4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_aNdtEGgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eqO6j9B5, 0, m, &cVar_eqO6j9B5_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_pmj5iBHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fwnNHNK2, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_C5crmj0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AdPVHZZQ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_7Qv6kCWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_liTdNEbW, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_xJRoKPhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gvy4SBIx, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Bnv7di6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1w7zjOi4_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_1w7zjOi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DRyGb8lU, HV_BINOP_DIVIDE, 1, m, &cBinop_DRyGb8lU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j3yhJbcH_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_r7kqxltX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_CbEGl6JC_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_BixwouTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_r7kqxltX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CbEGl6JC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DRyGb8lU, HV_BINOP_DIVIDE, 0, m, &cBinop_DRyGb8lU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_j3yhJbcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BixwouTQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_DRyGb8lU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EAMCiuSH, HV_BINOP_MULTIPLY, 1, m, &cBinop_EAMCiuSH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EAMCiuSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t626Ko4Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y8jn4drB_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_UdTXSp7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pg1aKEmd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_l8g0DyIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9iC4SpNH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_hKCgSRbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_bBb6u28S_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bBb6u28S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EAMCiuSH, HV_BINOP_MULTIPLY, 0, m, &cBinop_EAMCiuSH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wPpoGo7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_KEkFcuhU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KEkFcuhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e38mbNVk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_lsa9fgyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r7EOULvb, HV_BINOP_MULTIPLY, 1, m, &cBinop_r7EOULvb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xULCWQUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cBKMWtDD, 1, m, &cVar_cBKMWtDD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4AmClfbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ayfhCHKG, HV_BINOP_MULTIPLY, 1, m, &cBinop_ayfhCHKG_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_7Kht3Wxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_W5fRflXM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_W5fRflXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QlpOYTD7, HV_BINOP_MULTIPLY, 1, m, &cBinop_QlpOYTD7_sendMessage);
}

void Heavy_WSTD_EQ::cVar_cBKMWtDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5tRtj7Nq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_2FCH9opf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z5wZLjYs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_hKCgSRbn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UUr6PNxP_sendMessage);
}

void Heavy_WSTD_EQ::cVar_N01Dy80N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_wPpoGo7L_sendMessage);
}

void Heavy_WSTD_EQ::cCast_y8jn4drB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_l8g0DyIH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_t626Ko4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_UdTXSp7K_sendMessage);
}

void Heavy_WSTD_EQ::cSend_pg1aKEmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AWNizYCs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_9iC4SpNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_E15PK2fi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_hyWe9Odn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Udt0tiZI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_e38mbNVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2K8G2CZX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2K8G2CZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jf7bcjLV, HV_BINOP_MULTIPLY, 1, m, &cBinop_jf7bcjLV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jf7bcjLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cfREyQma_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cfREyQma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hyWe9Odn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_5tRtj7Nq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JIkX5Jj6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JIkX5Jj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Y8nD94J_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k1ZReQP1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MsTUm1Jf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4dPJa32Q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WmuRq7Ez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pmj5iBHO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_r7EOULvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C5crmj0D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ayfhCHKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Qv6kCWp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_QlpOYTD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xJRoKPhC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_vpiWRf2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N01Dy80N, 1, m, &cVar_N01Dy80N_sendMessage);
}

void Heavy_WSTD_EQ::cCast_kqpA7Kjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2FCH9opf, 0, m, &cVar_2FCH9opf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_z5wZLjYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N01Dy80N, 0, m, &cVar_N01Dy80N_sendMessage);
}

void Heavy_WSTD_EQ::cCast_UUr6PNxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cBKMWtDD, 0, m, &cVar_cBKMWtDD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MsTUm1Jf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_r7EOULvb, HV_BINOP_MULTIPLY, 0, m, &cBinop_r7EOULvb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_k1ZReQP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ayfhCHKG, HV_BINOP_MULTIPLY, 0, m, &cBinop_ayfhCHKG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4dPJa32Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WmuRq7Ez, HV_BINOP_MULTIPLY, 0, m, &cBinop_WmuRq7Ez_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9Y8nD94J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QlpOYTD7, HV_BINOP_MULTIPLY, 0, m, &cBinop_QlpOYTD7_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_FBkf8Q2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n0pdXuFS, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_zjsq49NU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8x77XGW8, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_3ihdOjso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rSzxnMeh, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_inEVYvGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6C3ptI4k, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_nj0SN0hH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_466yTklo, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_mF1EFyQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xGRKhOsj_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_xGRKhOsj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uRYUp9Wz, HV_BINOP_DIVIDE, 1, m, &cBinop_uRYUp9Wz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sSlIjZia_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_jDFYJkXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_PJGlILIY_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_rlWaGabF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_jDFYJkXF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PJGlILIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uRYUp9Wz, HV_BINOP_DIVIDE, 0, m, &cBinop_uRYUp9Wz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sSlIjZia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rlWaGabF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_uRYUp9Wz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QhUJH3bp, HV_BINOP_MULTIPLY, 1, m, &cBinop_QhUJH3bp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QhUJH3bp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_94aHxJ0N_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oW9UJ3SQ_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_mlmKafXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fek5YRsB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_OJe4ha6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SXbszDxm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FeBKWe7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_E0ouLOo2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_E0ouLOo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QhUJH3bp, HV_BINOP_MULTIPLY, 0, m, &cBinop_QhUJH3bp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_z2oXQ0t0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_3U0x0sca_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3U0x0sca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_t3Nknogd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_rIAgbCUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CHOrxyJ5, HV_BINOP_MULTIPLY, 1, m, &cBinop_CHOrxyJ5_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_a0Pw9BER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_OarKfnXI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OarKfnXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rIAgbCUm_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_vUiT5pME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BCWSLa1C_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BCWSLa1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jP3yD1P7, HV_BINOP_MULTIPLY, 1, m, &cBinop_jP3yD1P7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uZ53aCep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5hWq7rrO, HV_BINOP_MULTIPLY, 1, m, &cBinop_5hWq7rrO_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_g5gzgZdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_whDRuC1L_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_whDRuC1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uZ53aCep_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3HdYQByO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PZL30UIE, 1, m, &cVar_PZL30UIE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_URFuKyRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XS7dT96V, HV_BINOP_MULTIPLY, 1, m, &cBinop_XS7dT96V_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_kWKYoM3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_uFQCBv4l_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uFQCBv4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oBgRxAxp, HV_BINOP_MULTIPLY, 1, m, &cBinop_oBgRxAxp_sendMessage);
}

void Heavy_WSTD_EQ::cVar_PZL30UIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eTRBgHwq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_iBYO8RHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g6fEDp1o_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_FeBKWe7Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nw0xXmB2_sendMessage);
}

void Heavy_WSTD_EQ::cVar_7bRkfZRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_z2oXQ0t0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oW9UJ3SQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_OJe4ha6h_sendMessage);
}

void Heavy_WSTD_EQ::cCast_94aHxJ0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_mlmKafXX_sendMessage);
}

void Heavy_WSTD_EQ::cSend_fek5YRsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KkTONK6E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_SXbszDxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hVpfTqtp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_nVLccQPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_P3TYVpcd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_t3Nknogd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_q5jqZW1z_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_q5jqZW1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VET5sGEu, HV_BINOP_MULTIPLY, 1, m, &cBinop_VET5sGEu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VET5sGEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NCLTv4N0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NCLTv4N0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nVLccQPl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_eTRBgHwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8OhjejUF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8OhjejUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sZl0dKkZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1QZEfuNB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cLiQkR1r_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n2i0qsGX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mvXGwTNT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EThXKHc1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CHOrxyJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FBkf8Q2G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_jP3yD1P7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zjsq49NU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_5hWq7rrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3ihdOjso_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_XS7dT96V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_inEVYvGm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_oBgRxAxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nj0SN0hH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_izYMQvX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iBYO8RHh, 0, m, &cVar_iBYO8RHh_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Do9Dhnjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7bRkfZRZ, 1, m, &cVar_7bRkfZRZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_n2i0qsGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5hWq7rrO, HV_BINOP_MULTIPLY, 0, m, &cBinop_5hWq7rrO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sZl0dKkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_EThXKHc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CHOrxyJ5, HV_BINOP_MULTIPLY, 0, m, &cBinop_CHOrxyJ5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cLiQkR1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XS7dT96V, HV_BINOP_MULTIPLY, 0, m, &cBinop_XS7dT96V_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mvXGwTNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jP3yD1P7, HV_BINOP_MULTIPLY, 0, m, &cBinop_jP3yD1P7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1QZEfuNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oBgRxAxp, HV_BINOP_MULTIPLY, 0, m, &cBinop_oBgRxAxp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_nw0xXmB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PZL30UIE, 0, m, &cVar_PZL30UIE_sendMessage);
}

void Heavy_WSTD_EQ::cCast_g6fEDp1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7bRkfZRZ, 0, m, &cVar_7bRkfZRZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yqHRhYFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MKzhCUOQ, 1, m, &cIf_MKzhCUOQ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_MUfnQLHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1XFLEcvo, m);
}

void Heavy_WSTD_EQ::cBinop_kKN2j45C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MUfnQLHn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FxNi1kOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MKzhCUOQ, 0, m, &cIf_MKzhCUOQ_sendMessage);
}

void Heavy_WSTD_EQ::cVar_zaSizISU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZI7UyPHJ, HV_BINOP_DIVIDE, 0, m, &cBinop_ZI7UyPHJ_sendMessage);
}

void Heavy_WSTD_EQ::cVar_7aAsJz54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KWYwWKtb, HV_BINOP_DIVIDE, 1, m, &cBinop_KWYwWKtb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZI7UyPHJ, HV_BINOP_DIVIDE, 1, m, &cBinop_ZI7UyPHJ_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_MLzIOUvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4nLJKgUl, HV_BINOP_DIVIDE, 0, m, &cBinop_4nLJKgUl_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_DlgaRoQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4nLJKgUl, HV_BINOP_DIVIDE, 1, m, &cBinop_4nLJKgUl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_O9lyxxEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KWYwWKtb, HV_BINOP_DIVIDE, 0, m, &cBinop_KWYwWKtb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BhuGOluS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zaSizISU, 0, m, &cVar_zaSizISU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_upwAoUUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7aAsJz54, 0, m, &cVar_7aAsJz54_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KWYwWKtb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_MLzIOUvH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZI7UyPHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_DlgaRoQs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4nLJKgUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_VQDYtH7J_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_YPIYjaBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_kjT9czOd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yA5rcznJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_tuvfGzoJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VQDYtH7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_yA5rcznJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tuvfGzoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_YPIYjaBz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kjT9czOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0tj8GUfK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_sPMWM4CY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_nWdb6sXM_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WDoslhfh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_tlKtjdJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_nWdb6sXM_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WDoslhfh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_kYJcPgoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_nWdb6sXM_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WDoslhfh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_LHS3RgiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_nWdb6sXM_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WDoslhfh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_0tj8GUfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_nWdb6sXM_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WDoslhfh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_qlpPlPp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_vyLOtvLt, 0, m, &cVar_vyLOtvLt_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_bzR4RdL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_aVQubAsN, 0, m, &cVar_aVQubAsN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wHU76vPS, 0, m, &cVar_wHU76vPS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OmhaNkc4, 0, m, &cVar_OmhaNkc4_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_n8xc6o3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aVQubAsN, 0, m, &cVar_aVQubAsN_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_vzNNcuCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wHU76vPS, 0, m, &cVar_wHU76vPS_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_tb6H3aWT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OmhaNkc4, 0, m, &cVar_OmhaNkc4_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_vnRpbOHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sjYkaP5I, 0, m, &cVar_sjYkaP5I_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ycyxJzS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dmo3DuIE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tvzkm2ql_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_8hN75bep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6y6AcBQ5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9O5GiAEy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8ARqW0Po_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_hPyRIota_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pKKy9wew_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KmXmIhKo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6rUea71h_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_0zWrYVET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QSGUJr2L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6jsRa7hZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EyjEHY9W_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_GycH2qZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YEJDCW8x_sendMessage(_c, 0, m);
  cMsg_5xfJbP97_sendMessage(_c, 0, m);
  cMsg_i9xsdpsa_sendMessage(_c, 0, m);
  cMsg_hZb5ym3G_sendMessage(_c, 0, m);
  cMsg_Bnv7di6X_sendMessage(_c, 0, m);
  cMsg_mF1EFyQF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_w0P6ihWF, 0, m, &cVar_w0P6ihWF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sjYkaP5I, 0, m, &cVar_sjYkaP5I_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_T9nwT3Aw, 0, m, &cVar_T9nwT3Aw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wCZmAst9, 0, m, &cVar_wCZmAst9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2FCH9opf, 0, m, &cVar_2FCH9opf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iBYO8RHh, 0, m, &cVar_iBYO8RHh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_r25jmJmK, 0, m, &cVar_r25jmJmK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6KOyWkKF, 0, m, &cVar_6KOyWkKF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TKU700Im, 0, m, &cVar_TKU700Im_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xGKTlK5z, 0, m, &cVar_xGKTlK5z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yeWxN7I8, 0, m, &cVar_yeWxN7I8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dkBMDHB2, 0, m, &cVar_dkBMDHB2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NjI1hE9n, 0, m, &cVar_NjI1hE9n_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H594JBEb, 0, m, &cVar_H594JBEb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vXd8BYpw, 0, m, &cVar_vXd8BYpw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BW3Bbtig, 0, m, &cVar_BW3Bbtig_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Oz6ac1Kr, 0, m, &cVar_Oz6ac1Kr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PYqIhsZw, 0, m, &cVar_PYqIhsZw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RqS8fBDd, 0, m, &cVar_RqS8fBDd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ky9cmJcP, 0, m, &cVar_Ky9cmJcP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1TLpV01N, 0, m, &cVar_1TLpV01N_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6u28XLTw, 0, m, &cVar_6u28XLTw_sendMessage);
  cMsg_bzR4RdL7_sendMessage(_c, 0, m);
  cMsg_qlpPlPp6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_KeS9LWiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ujNtZGnb, HV_BINOP_MULTIPLY, 0, m, &cBinop_ujNtZGnb_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_okruP0B5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Vgdkv6jh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0UmL64nL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qKhGSYJ8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_70fDWDA6_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_IJFtTV3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ALVoIzk6_sendMessage);
  cMsg_AmMUmKCk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_h9v7t2AR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dnE6Bw64, HV_BINOP_MULTIPLY, 0, m, &cBinop_dnE6Bw64_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_tR0v7pkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_SdK5vBHZ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_lBPvZZez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qeaRKAEC, HV_BINOP_MULTIPLY, 1, m, &cBinop_qeaRKAEC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_bWzauPQW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VorQiy3G_sendMessage);
  cMsg_lEtN6yfh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_SgbgVlef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ivs0sSkq, HV_BINOP_MULTIPLY, 0, m, &cBinop_ivs0sSkq_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ezLwFjlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DXQ3SuZp_sendMessage(_c, 0, m);
  cMsg_oVxcbalH_sendMessage(_c, 0, m);
  cMsg_0xWJiYxf_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_j8rk5xJ1_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_iDsR6sj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jEWBc9aX_sendMessage);
  cMsg_p3EdGTFf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_m13JC8qj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2FCH9opf, 0, m, &cVar_2FCH9opf_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_kbvi9wr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vpiWRf2e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kqpA7Kjc_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_1tWfOj4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mjfigpf1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KVDyKKWp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K4iBp7Jz_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_nHCYNoRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_igRq1Mkb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mHHXKkyG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KGwjWC9t_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_5e2UJcDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N7nNrvHe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iItLpJbc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4CUFfPqi_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_g6lNnF9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ESBXHOJS, HV_BINOP_MULTIPLY, 0, m, &cBinop_ESBXHOJS_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ekjt0eL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_trd20ejU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Zm7hwySG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_PbFkyGX6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_uTJF122i_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_FJrYEQ6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_OgwqFQ61_sendMessage);
  cMsg_CipllCTB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_AWNizYCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jf7bcjLV, HV_BINOP_MULTIPLY, 0, m, &cBinop_jf7bcjLV_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_E15PK2fi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_4AmClfbN_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Udt0tiZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WmuRq7Ez, HV_BINOP_MULTIPLY, 1, m, &cBinop_WmuRq7Ez_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_lsa9fgyF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xULCWQUd_sendMessage);
  cMsg_7Kht3Wxn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_KkTONK6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VET5sGEu, HV_BINOP_MULTIPLY, 0, m, &cBinop_VET5sGEu_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_hVpfTqtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a0Pw9BER_sendMessage(_c, 0, m);
  cMsg_vUiT5pME_sendMessage(_c, 0, m);
  cMsg_g5gzgZdw_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_URFuKyRg_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_P3TYVpcd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3HdYQByO_sendMessage);
  cMsg_kWKYoM3k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_7u5eT2JW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vyLOtvLt, 0, m, &cVar_vyLOtvLt_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_MVMAqyeh, VOf(Bf0));
    __hv_varread_f(&sVarf_HoQZ2v6O, VOf(Bf1));
    __hv_varread_f(&sVarf_Rxx6aCR0, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_9qmbTFSr, VOf(Bf0));
    __hv_varread_f(&sVarf_lPCGa43t, VOf(Bf1));
    __hv_varread_f(&sVarf_QqVNBhLX, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_DpD07bQu, VOf(Bf0));
    __hv_line_f(&sLine_feYBRk4I, VOf(Bf1));
    __hv_line_f(&sLine_B9ItsWCA, VOf(Bf4));
    __hv_line_f(&sLine_jGlnr1lF, VOf(Bf5));
    __hv_line_f(&sLine_jog8aWbg, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_A6wLjBxN, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_mkiJYG07, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_iYvlwkHV, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_NSAt03Yf, VOf(Bf1));
    __hv_line_f(&sLine_c6FdOEdK, VOf(Bf0));
    __hv_line_f(&sLine_zpYH1D5C, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_lmcRdsEi, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_YM1Rvw3L, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_rGZ9mBSk, VOf(Bf7));
    __hv_line_f(&sLine_r9Y1s6bS, VOf(Bf1));
    __hv_line_f(&sLine_PW4w6Ga4, VOf(Bf4));
    __hv_line_f(&sLine_T9fxe49b, VOf(Bf6));
    __hv_line_f(&sLine_9ouyFnr3, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_b6ZTx1Ak, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_YvRQejEd, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_MVMAqyeh, VIf(Bf5));
    __hv_varwrite_f(&sVarf_HoQZ2v6O, VIf(Bf0));
    __hv_varwrite_f(&sVarf_Rxx6aCR0, VIf(Bf6));
    __hv_line_f(&sLine_VAlCoJtw, VOf(Bf6));
    __hv_line_f(&sLine_Vy73cukN, VOf(Bf0));
    __hv_line_f(&sLine_wK9gfWib, VOf(Bf5));
    __hv_line_f(&sLine_R9e2472K, VOf(Bf8));
    __hv_line_f(&sLine_S08T0LJX, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_vaCQd3xC, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_5xfqULeR, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_fwnNHNK2, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_AdPVHZZQ, VOf(Bf0));
    __hv_line_f(&sLine_liTdNEbW, VOf(Bf6));
    __hv_line_f(&sLine_gvy4SBIx, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_rrUUG2Lr, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_1XFLEcvo, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_n0pdXuFS, VOf(Bf1));
    __hv_line_f(&sLine_8x77XGW8, VOf(Bf0));
    __hv_line_f(&sLine_rSzxnMeh, VOf(Bf5));
    __hv_line_f(&sLine_6C3ptI4k, VOf(Bf4));
    __hv_line_f(&sLine_466yTklo, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_XtRHipMX, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_zo2JYsI9, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_9qmbTFSr, VIf(Bf8));
    __hv_varwrite_f(&sVarf_lPCGa43t, VIf(Bf6));
    __hv_varwrite_f(&sVarf_QqVNBhLX, VIf(Bf4));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
